#ifdef HAVE_OSC

#ifndef __OSC_H__
#define __OSC_H__

#include <pthread.h>
#include <lo/lo.h>
#include "speciallist.h"

typedef struct _osc_info{
	lo_server_thread st;
	speciallist_t	*looperdatalist;
	int 		quit;
} osc_info_t;

osc_info_t*  osc_info_new (speciallist_t* looperdatalist);
void         osc_info_destroy (osc_info_t* oinfo);

#endif /* __OSC_H__ */
#endif /* HAVE_OSC */


